@@ -32,6 +32,7 @@ class ModelVariable(ABC):
         description: Optional[str] = None,
         initial: Optional[Fmi3Initial] = None,
         variability: Optional[Fmi3Variability] = None,
+        declared_type: Optional[str] = None,
         getter: Any = None,
         setter: Any = None
     ):
@@ -46,6 +47,7 @@ class ModelVariable(ABC):
             "causality": causality,
             "variability": variability,
             "initial": initial,
+            "declaredType": declared_type,
             # 'canHandleMultipleSetPerTimeInstant': # Only for ME
         }
         self._extras = {}
@@ -81,6 +83,17 @@ class ModelVariable(ABC):
             raise RuntimeError("Value reference already set.")
         self.__attrs["valueReference"] = value
 
+    @property
+    def declared_type(self) -> str:
+        """str: declared type"""
+        return self.__attrs["declaredType"]
+
+    @declared_type.setter
+    def declared_type(self, value: str):
+        if self.__attrs["declaredType"] is not None:
+            raise RuntimeError("Declared type already set.")
+        self.__attrs["declaredType"] = value
+    
     @property
     def variability(self) -> Optional[Fmi3Variability]:
         """:obj:`Fmi3Variability` or None: Variable variability - None if not set"""
@@ -144,11 +157,12 @@ class Dimension(object):
         ele = Element("Dimension", attrib)
         return ele
 
-class Real(ModelVariable):
-    def __init__(self, name: str, start: Optional[Any] = None, derivative: Optional[Any] = None, dimensions: List[Dimension] = [], **kwargs):
+class Float64(ModelVariable):
+    def __init__(self, name: str, start: Optional[Any] = None, derivative: Optional[Any] = None, dimensions: List[Dimension] = [], unit: Optional[str] = None, **kwargs):
         super().__init__(name, **kwargs)
         self.__attrs = {"start": start, "derivative": derivative}
         self._type = "Float64"
+        self._unit = unit
         if dimensions:
             check_numpy()
         self.__dimensions = dimensions
@@ -160,6 +174,14 @@ class Real(ModelVariable):
     @start.setter
     def start(self, value: float):
         self.__attrs["start"] = value
+    
+    @property
+    def unit(self) -> Optional[Any]:
+        return self._unit
+
+    @unit.setter
+    def unit(self, value: str):
+        self._unit = value
 
     @property
     def derivative(self):
@@ -169,6 +191,7 @@ class Real(ModelVariable):
     def dimensions(self) -> List[Dimension]:
         return self.__dimensions
 
+
     def to_xml(self) -> Element:
         attrib = dict()
         for key, value in self.__attrs.items():
@@ -181,6 +204,10 @@ class Real(ModelVariable):
                 else:
                     output = f"{value:.16g}"
                 attrib[key] = output
+
+        if self.unit:
+            attrib["unit"] = self.unit
+
         self._extras = attrib
         parent = super().to_xml()
 
@@ -193,7 +220,7 @@ class Real(ModelVariable):
         return reduce(lambda x, dim: x * int(dim.size(vars)), self.__dimensions, 1)
 
 
-class Integer(ModelVariable):
+class Int32(ModelVariable):
     def __init__(self, name: str, start: Optional[Any] = None, **kwargs):
         super().__init__(name, **kwargs)
         self.__attrs = {"start": start}
@@ -204,7 +231,31 @@ class Integer(ModelVariable):
         return self.__attrs["start"]
 
     @start.setter
-    def start(self, value: float):
+    def start(self, value: int):
+        self.__attrs["start"] = value
+
+    def to_xml(self) -> Element:
+        attrib = dict()
+        for key, value in self.__attrs.items():
+            if value is not None:
+                attrib[key] = str(value)
+        self._extras = attrib
+        parent = super().to_xml()
+
+        return parent
+        
+class Int64(ModelVariable):
+    def __init__(self, name: str, start: Optional[Any] = None, **kwargs):
+        super().__init__(name, **kwargs)
+        self.__attrs = {"start": start}
+        self._type = "Int64";
+
+    @property
+    def start(self) -> Optional[Any]:
+        return self.__attrs["start"]
+
+    @start.setter
+    def start(self, value: int):
         self.__attrs["start"] = value
 
     def to_xml(self) -> Element:
@@ -228,7 +279,7 @@ class UInt64(ModelVariable):
         return self.__attrs["start"]
 
     @start.setter
-    def start(self, value: float):
+    def start(self, value: int):
         self.__attrs["start"] = value
 
     def to_xml(self) -> Element:
@@ -289,3 +340,35 @@ class String(ModelVariable):
         parent = super().to_xml()
 
         return parent
+    
+class Enumeration(ModelVariable):
+    def __init__(self, name: str, start: Optional[Any] = None, declared_type: Optional[Any] = None, **kwargs):
+        super().__init__(name, **kwargs)
+        self.__attrs = {"start": start, "declaredType": declared_type}
+        self._type = "Enumeration"
+
+    @property
+    def start(self) -> Optional[Any]:
+        return self.__attrs["start"]
+
+    @start.setter
+    def start(self, value: float):
+        self.__attrs["start"] = value
+
+    @property
+    def declared_type(self) -> Optional[Any]:
+        return self.__attrs["declaredType"]
+
+    @declared_type.setter
+    def declared_type(self, value: float):
+        self.__attrs["declaredType"] = value
+
+    def to_xml(self) -> Element:
+        attrib = dict()
+        for key, value in self.__attrs.items():
+            if value is not None:
+                attrib[key] = str(value)
+        self._extras = attrib
+        parent = super().to_xml()
+
+        return parent
